pub struct Sender<T> { /* private fields */ }Expand description
Tracked bounded sender half of an mpsc channel.
Implementations
Sourceimpl<T> Sender<T>
impl<T> Sender<T>
Sourcepub async fn send(&self, value: T) -> Result<(), SendError<T>>
pub async fn send(&self, value: T) -> Result<(), SendError<T>>
Send a value, waiting if the channel is full.
Errors
Returns an error if the receiver has been dropped.
Sourcepub fn try_send(&self, value: T) -> Result<(), TrySendError<T>>
pub fn try_send(&self, value: T) -> Result<(), TrySendError<T>>
Try to send a value without waiting.
Sourcepub fn max_capacity(&self) -> usize
pub fn max_capacity(&self) -> usize
Get the maximum capacity.
Sourcepub fn metrics(&self) -> ChannelMetrics
pub fn metrics(&self) -> ChannelMetrics
Get current metrics for this channel.